import subprocess
from pygeoweaver.utils import download_geoweaver_jar, get_geoweaver_jar_path, get_java_bin_path, get_root_dir


def import_workflow(workflow_zip_file_path):
  """
  Usage: <main class> import workflow <workflow_zip_file_path>
  import a workflow from file
        <workflow_zip_file_path>
          Geoweaver workflow zip file path
  """
  if not workflow_zip_file_path:
        raise RuntimeError("Workflow zip file path is missing")
  download_geoweaver_jar()
  subprocess.run([get_java_bin_path(), "-jar", get_geoweaver_jar_path(), "import", 
                  "workflow", workflow_zip_file_path], cwd=f"{get_root_dir()}/")




import subprocess
from pygeoweaver.utils import download_geoweaver_jar, get_geoweaver_jar_path, get_java_bin_path, get_root_dir


def show_history(history_id):
    """
    Workflow and process history uses the same method to check
    """
    if not history_id:
        raise RuntimeError("history id is missing")
    download_geoweaver_jar()
    subprocess.run([get_java_bin_path(), "-jar", get_geoweaver_jar_path(), "history", history_id], cwd=f"{get_root_dir()}/")



"""
Detail subcommand
"""

import subprocess
from pygeoweaver.utils import download_geoweaver_jar, get_geoweaver_jar_path, get_java_bin_path, get_root_dir


def detail_workflow(workflow_id):
    if not workflow_id:
        raise RuntimeError("Workflow id is missing")
    download_geoweaver_jar()
    subprocess.run([get_java_bin_path(), "-jar", get_geoweaver_jar_path(), "detail", f"--workflow-id={workflow_id}"], 
                   cwd=f"{get_root_dir()}/")


def detail_process(process_id):
    if not process_id:
        raise RuntimeError("Process id is missing")
    download_geoweaver_jar()
    subprocess.run([get_java_bin_path(), "-jar", get_geoweaver_jar_path(), "detail", f"--process-id={process_id}"], 
                   cwd=f"{get_root_dir()}/")

def detail_host(host_id):
    if not host_id:
        raise RuntimeError("Host id is missing")
    download_geoweaver_jar()
    subprocess.run([get_java_bin_path(), "-jar", get_geoweaver_jar_path(), "detail", f"--host-id={host_id}"], 
                   cwd=f"{get_root_dir()}/")